%global srcname pyrsistent
%global __pytest /usr/bin/pytest-3.8

%global common_description %{expand:
Pyrsistent is a number of persistent collections (by some referred to as
functional data structures). Persistent in the sense that they are
immutable.

All methods on a data structure that would normally mutate it instead
return a new copy of the structure containing the requested updates. The
original structure is left untouched.}

Name:           python38-%{srcname}-epel
Summary:        Persistent/Functional/Immutable data structures
Version:        0.17.3
Release:        1%{?dist}

# The entire source is MIT, except pyrsistent/_toolz.py which is BSD.
License:        MIT and BSD
URL:            https://github.com/tobgu/pyrsistent/
Source0:        %{url}/archive/v%{version}/%{srcname}-%{version}.tar.gz

# Relax dependencies specified in setup.py (allow newer pytest/hypothesis)
Patch0:         00-relax-dependencies.patch

BuildRequires:  gcc
BuildRequires:  python38-devel
BuildRequires:  python38-rpm-macros
BuildRequires:  make

# ============================================================================
# From requirements.txt:

# hypothesis
BuildRequires:  python3.8dist(hypothesis)

# ----------------------------------------------------------------------------
# We do not need these, since we are not running the memorytest* environment
# from tox.ini.
# ----------------------------------------------------------------------------
# memory-profiler==0.57.0
# psutil==5.7.0

# ----------------------------------------------------------------------------
# We do not need this, since we are not running the benchmarks from
# performance_suites/.
# ----------------------------------------------------------------------------
# pyperform

# pytest
BuildRequires:  python3.8dist(pytest)
# Sphinx
BuildRequires:  python3dist(sphinx)
# sphinx-rtd-theme==0.1.5
BuildRequires:  python3dist(sphinx-rtd-theme)

# ----------------------------------------------------------------------------
# We do not need this, since we are not using tox to run the tests.
# ----------------------------------------------------------------------------
# tox

# setuptools>=0.16.1
BuildRequires:  python3.8dist(setuptools) >= 0.16.1

# ----------------------------------------------------------------------------
# We do not need these for the RPM build either.
# ----------------------------------------------------------------------------
# twine>=3.2
# pip>=20.2.3

# ============================================================================
# From setup_requires in setup.py, when tests are to be executed:
#BuildRequires:  python3.8dist(pytest-runner)

# Note that pyrsistent/_toolz.py contains a bit of code ported from toolz, but
# not enough to constitute a bundled dependency.

%description %{common_description}


%package -n     python38-%{srcname}
Summary:        %{summary}

%description -n python38-%{srcname} %{common_description}


%package        doc
Summary:        Documentation for %{srcname}

BuildArch:      noarch

%description doc %{common_description}


%prep
%autosetup -n %{srcname}-%{version} -p1


%build
%py3_build

# Default SPHINXOPTS are '-W -n', but -W turns warnings into errors and there
# are some warnings. We want to build the documentation as best we can anyway.
# Additionally, we parallelize sphinx-build.
%make_build -C docs html SPHINXOPTS='-n %{?_smp_mflags}'
rm -f docs/build/html/.buildinfo


%install
%py3_install


%check
%pytest
# See tox.ini:
env PYTHONHASHSEED=0 %pytest --doctest-modules %{srcname}


%files -n python38-%{srcname}
%license LICENCE.mit

%pycached %{python3_sitearch}/_pyrsistent_version.py

%{python3_sitearch}/%{srcname}/
%{python3_sitearch}/pvectorc.cpython-3*.so
%{python3_sitearch}/%{srcname}-%{version}-py%{python3_version}.egg-info/


%files doc
%license LICENCE.mit
%doc CHANGES.txt
%doc README.rst
%doc docs/build/html


%changelog
* Sat Jun 25 2022 Orion Poplawski <orion@nwra.com> - 0.17.3-1
- Build for EPEL8 Python 3.8
